==> alf-converter-1.0.1.tgz: package/lib/bin.js <==
#!/usr/bin/env node
'use strict';

var _converter = require('./converter');

var _converter2 = _interopRequireDefault(_converter);

var _detector = require('./detector');

var _detector2 = _interopRequireDefault(_detector);

var _furmat = require('furmat');

var _furmat2 = _interopRequireDefault(_furmat);

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _getStdin = require('get-stdin');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var format = (0, _furmat2.default)();
var options = {
  'format': {
    alias: 'f',
    demand: false,
    describe: 'source file format'
  },

  'version': {
    alias: 'v',
    demand: false,
    describe: 'source file schema version'
  },

  'output': {
    alias: 'o',
    demand: false,
    describe: 'write output to <file>',
    type: 'string'
  },

  'token': {
    alias: 't',
    demand: false,
    describe: 'use <token> for missing service.token',
    type: 'string'
  },

  'help': {
    alias: 'h'
  }
};

(0, _getStdin.buffer)().then(function (stdin) {
  var argv = _yargs2.default.demand(stdin.length ? 0 : 1).usage('Usage: $0 <file...> [options]').help('help').options(options).argv;

  // add stdin to list of files
  if (stdin.length) {
    argv._.push(stdin);
  }

  argv._.forEach(function (file) {
    (0, _utils.read)(file).then(_utils.parse).then(function (file) {
      return (0, _detector2.default)(file.content, argv.format, argv.version).then(function (result) {
        console.log(format('%s:green [%s:yellow:italic] is %s:cyan version: %s:magenta', '✔️', file.name, result.format, result.version));

        if (argv.token) result.serviceToken = argv.token;

        return result;
      }).then(function (result) {
        return (0, _converter2.default)(result.data, result);
      }).then(function (output) {
        if (!argv.output) {
          return console.log(output);
        }

        return (0, _utils.write)(argv.output, output).then(function () {
          return console.log(format('%s:green [%s:yellow:italic] converted successfully to latest ALF at %s:magenta', '✔️', file.name, argv.output));
        });
      });
    }).catch(function (err) {
      if (err instanceof SyntaxError) {
        return console.error(format('%s:red [%s:yellow:italic] failed to read JSON: %s:red', '✖', err.file, err.message));
      }

      if (err.code === 'ENOENT') {
        return console.error(format('%s:red [%s:yellow:italic] %s:red', '✖', err.file, 'no such file or directory'));
      }

      console.error(format('%s:red [%s:yellow:italic] an unknown error has occured: %s:red', '✖', err.file, err.message));
    });
  });
});

==> alf-converter-1.2.1.tgz: package/lib/bin.js <==
#!/usr/bin/env node
'use strict';

var _converter = require('./converter');

var _converter2 = _interopRequireDefault(_converter);

var _detector = require('./detector');

var _detector2 = _interopRequireDefault(_detector);

var _furmat = require('furmat');

var _furmat2 = _interopRequireDefault(_furmat);

var _alfValidator = require('alf-validator');

var _alfValidator2 = _interopRequireDefault(_alfValidator);

var _error = require('alf-validator/lib/error');

var _error2 = _interopRequireDefault(_error);

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _getStdin = require('get-stdin');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var format = (0, _furmat2.default)();
var options = {
  format: {
    alias: 'f',
    demand: false,
    describe: 'source file format'
  },

  version: {
    alias: 'v',
    demand: false,
    describe: 'source file schema version'
  },

  output: {
    alias: 'o',
    demand: false,
    describe: 'write output to <file>',
    type: 'string'
  },

  token: {
    alias: 't',
    demand: false,
    describe: 'use <token> for missing service.token',
    type: 'string'
  },

  help: {
    alias: 'h'
  }
};

(0, _getStdin.buffer)().then(function (stdin) {
  var argv = _yargs2.default.demand(stdin.length ? 0 : 1).usage('Usage: $0 <file...> [options]').help('help').options(options).argv;

  // add stdin to list of files
  if (stdin.length) {
    argv._.push(stdin);
  }

  argv._.forEach(function (file) {
    (0, _utils.read)(file).then(_utils.parse).then(function (file) {
      return (0, _detector2.default)(file.content, argv.format, argv.version).then(function (result) {
        console.log(format('%s:green [%s:yellow:italic] is %s:cyan version: %s:magenta', '✔️', file.name, result.format, result.version));

        if (argv.token) result.serviceToken = argv.token;

        return result;
      }).then(function (result) {
        return (0, _converter2.default)(result.data, result);
      })
      // strip additional properties
      .then(function (result) {
        return (0, _alfValidator2.default)(result, 'latest', true);
      }).then(function (result) {
        var output = JSON.stringify(result, null, 2);

        if (!argv.output) {
          return console.log(output);
        }

        return (0, _utils.write)(argv.output, output).then(function () {
          return console.log(format('%s:green [%s:yellow:italic] converted successfully to latest ALF at %s:magenta', '✔️', file.name, argv.output));
        });
      }).catch(function (err) {
        if (err instanceof _error2.default) {
          return err.errors.forEach(function (details) {
            return console.error(format('%s:red [%s:yellow:italic] failed validation: %s:red (%s:cyan:italic: %s:magenta:italic)', '✖', file.name, details.message, details.field, details.value));
          });
        }
      });
    }).catch(function (err) {
      if (err.code === 'ENOENT') {
        return console.error(format('%s:red [%s:yellow:italic] %s:red', '✖', err.file, 'no such file or directory'));
      }

      if (err instanceof SyntaxError) {
        return console.error(format('%s:red [%s:yellow:italic] failed to read JSON: %s:red', '✖', err.file, err.message));
      }

      console.error(format('%s:red an unknown error has occured: %s:red', '✖', err.message));
    });
  });
});
